<?php

/**
 * The dashboard-specific functionality of the plugin.
 *
 * @link:       https://www.ulisesfreitas.com/plugins/
 * @since      1.0.0
 *
 * @package    Legal_Manager
 * @subpackage Legal_Manager/includes
 * @author     UlisesFreitas <ulises.freitas@gmail.com>
 *         
 */

class Legal_Manager_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $name    The ID of this plugin.
	 */
	private $name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @var      string    $name       The name of this plugin.
	 * @var      string    $version    The version of this plugin.
	 */
	public function __construct( $name, $version ) {

		$this->name = $name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the Dashboard.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Legal_Manager_Admin_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Legal_Manager_Admin_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->name, plugin_dir_url( __FILE__ ) . 'css/legal-manager-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the dashboard.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Legal_Manager_Admin_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Legal_Manager_Admin_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->name, plugin_dir_url( __FILE__ ) . 'js/legal-manager-admin.js', array( 'jquery' ), $this->version, FALSE );
        

	}

	
	/**
	 * Add links to plugin's description in plugins table
	 *
	 * @param array  $links  Initial list of links.
	 * @param string $file   Basename of current plugin.
	 *
	 * @return array
	 */
	public function legal_manager_plugin_meta_links($links, $file)
	{
		
		//legal-manager/legal-manager.php
		if ($file !== 'legal-manager/legal-manager.php') {
		return $links;
		}
		//admin_url( 'index.php?page=legal-wizard' )
		$settings_link = '<a target="_self" href="' . admin_url( 'index.php?page=legal-wizard' ) . '" title="' . __('Settings', LEGAL_MANAGER_PLUGIN_NAME) . '">' . __('Settings', LEGAL_MANAGER_PLUGIN_NAME) . '</a>';
		$links[] = $settings_link;
	
		return $links;
	}




}
