<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * Dashboard. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * this starts the plugin.
 *
 * @link:             https://www.ulisesfreitas.com/plugins/
 * @since             1.0.0
 * @package           Legal_Manager
 *
 * @wordpress-plugin
 * Plugin Name:       Legal Manager
 * Plugin URI:        https://www.ulisesfreitas.com/plugins/
 * Description:       Plugin to create legal pages, legal notice, privacy policy, cookies policy, sitemap page, also allows you to install GDPR cookies compliance and WP Sitemap Page.
 * Version:           1.0.0
 * Require PHP:       5.6
 * Author:            UlisesFreitas
 * Author URI:        https://www.ulisesfreitas.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       legal-manager
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

define( 'LEGAL_MANAGER_PLUGIN_NAME', 'legal-manager' );
define( 'LEGAL_MANAGER_PATH', plugin_dir_path( __FILE__ ) );
define( 'LEGAL_MANAGER_URL', plugin_dir_url( __FILE__ ) );

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'LEGAL_MANAGER_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 */
require_once LEGAL_MANAGER_PATH . 'includes/class-legal-manager-activator.php';

/**
 * The code that runs during plugin deactivation.
 */
require_once LEGAL_MANAGER_PATH . 'includes/class-legal-manager-deactivator.php';

/** This action is documented in includes/class-legal-manager-activator.php */
register_activation_hook( __FILE__, array( 'Legal_Manager_Activator', 'activate' ) );

/** This action redirect the user to wizard after activation, I do not know which will work if admin_init or activated_plugin */
//add_action('admin_init', array( 'Legal_Manager_Activator', 'legal_manager_activation_redirect' ) );
add_action( 'activated_plugin', array('Legal_Manager_Activator','legal_manager_activation_redirect') );

/** This action is documented in includes/class-legal-manager-deactivator.php */
register_deactivation_hook( __FILE__, array( 'Legal_Manager_Deactivator', 'deactivate' ) );

/**
 * The core plugin class that is used to define internationalization,
 * dashboard-specific hooks, and public-facing site hooks.
 */
require_once LEGAL_MANAGER_PATH . 'includes/class-legal-manager.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function Legal_Manager_Run() {

	$plugin = new Legal_Manager();
	$plugin->run();

}
Legal_Manager_Run();
